<?php
/**
 * Redux functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Redux
 */

/**
 * Define Theme Name
 */
$redux_themename = get_option( 'stylesheet' );
$redux_themename = preg_replace("/\W/", "_", strtolower( $redux_themename ) );
define( 'REDUX_THEME_NAME', $redux_themename );
	
/**
 * Define Directory Location Constants
 */
define( 'REDUX_PARENT_DIR', get_template_directory() );
define( 'REDUX_CHILD_DIR', get_stylesheet_directory() );

/**
 * Define URL Location Constants
 */
define( 'REDUX_PARENT_URL', get_template_directory_uri() );
define( 'REDUX_CHILD_URL', get_stylesheet_directory_uri() );

if ( ! function_exists( 'redux_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function redux_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on components, use a find and replace
	 * to change 'redux' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'redux', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	add_image_size( 'redux-featured-image', 640, 9999 );
	add_image_size( 'redux-carousel', 1280, 768, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'header-menu' => esc_html__( ' Header Menu', 'redux' ),
		'social-menu' => esc_html__( ' Social Menu', 'redux' ),
		) );

	/**
	 * Add support for core custom logo.
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 160,
		'width'       => 480,
		'flex-width'  => false,
		'flex-height' => false,
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'redux_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'redux_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function redux_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'redux_content_width', 640 );
}
add_action( 'after_setup_theme', 'redux_content_width', 0 );

/**
 * Modify Custom Logo HTML
 */

function modify_logo_class($html) {
	$html = str_replace('class="custom-logo-link"', 'class="logo-wrap"', $html);
	$html = str_replace('class="custom-logo"', 'class="redux-logo"', $html);
	return $html;
}

add_filter('get_custom_logo','modify_logo_class');

/**
 * Return early if Custom Logos are not available.
 *
 * @todo Remove after WP 4.7
 */
function redux_the_custom_logo() {
	if ( ! function_exists( 'the_custom_logo' ) ) {
		return;
	} else {
		the_custom_logo();
	}
}

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function redux_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Main Sidebar', 'redux' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Header Sidebar', 'redux' ),
		'id'            => 'sidebar-header',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
}
add_action( 'widgets_init', 'redux_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function redux_scripts() {
	
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
	
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/font-awesome/css/font-awesome' . $min . '.css', '', '4.7.0' );
	
	wp_enqueue_style( 'redux-google-fonts', '//fonts.googleapis.com/css?family=Rubik:300,400,500,700|Yantramanav:300,400,500,700&amp;subset=devanagari' );
		
	wp_enqueue_style( 'flickity-style', get_template_directory_uri() . '/assets/flickity/flickity' . $min . '.css', '', '4.7.0' );

	wp_enqueue_style( 'redux-style', get_stylesheet_uri() );

	wp_enqueue_script( 'redux-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array('jquery'), '20151215', true );

	wp_enqueue_script( 'redux-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );
	
	wp_enqueue_script( 'flickity-js', get_template_directory_uri() . '/assets/flickity/flickity.pkgd' . $min . '.js', array('jquery'), '20151215', true );
	
	wp_enqueue_script( 'custom-js', get_template_directory_uri() . '/assets/js/custom.js', array('jquery'), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'redux_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Retrieve and handle theme options.
 */
function redux_options( $id, $default = false ) {

   // getting options value
   $redux_options = get_theme_mod( REDUX_THEME_NAME );
   if ( isset( $redux_options[ $id ] ) ) {
      return $redux_options[ $id ];
   } else {
      return $default;
   }
}