<?php
/**
 * Redux Theme Customizer
 *
 * @package Redux
 */

/**
 * Add Other Customizer Files
 */

function redux_load_customize_controls() {

	require_once( get_template_directory() . '/inc/customizer/customizer-pro/class-customize.php' );
	require_once( get_template_directory() . '/inc/customizer/customizer-checkbox-multiple/checkbox-multiple.php');
    
}

add_action( 'customize_register', 'redux_load_customize_controls', 0 );

/**
 * Add Category Control
 */
if (class_exists('WP_Customize_Control')) {
    class WP_Customize_Category_Control extends WP_Customize_Control {
        /**
         * Render the control's content.
         *
         * @since 3.4.0
         */
        public function render_content() {
            $dropdown = wp_dropdown_categories(
                array(
                    'name'              => '_customize-dropdown-categories-' . $this->id,
                    'echo'              => 0,
                    'show_option_none'  => __( '&mdash; Select &mdash;', 'redux' ),
                    'option_none_value' => '0',
                    'selected'          => $this->value(),
                )
            );
 
            // Hackily add in the data link parameter.
            $dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );
 
            printf(
                '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
                $this->label,
                $dropdown
            );
        }
    }
}

/**
 * Add Tag Control
 */
if (class_exists('WP_Customize_Control')) {
    class WP_Customize_Tag_Control extends WP_Customize_Control {
        /**
         * Render the control's content.
         *
         * @since 3.4.0
         */
        public function render_content() {
            $dropdown = wp_dropdown_categories(
                array(
                	'taxonomy'           => 'post_tag',
                    'name'              => '_customize-dropdown-tags-' . $this->id,
                    'echo'              => 0,
                    'show_option_none'  => __( '&mdash; Select &mdash;', 'redux' ),
                    'option_none_value' => '0',
                    'selected'          => $this->value(),
                )
            );
 
            // Hackily add in the data link parameter.
            $dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );
 
            printf(
                '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
                $this->label,
                $dropdown
            );
        }
    }
}

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function redux_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	
   // Start of the General Site Options
   $wp_customize->add_panel('redux_general_options', array(
      'capabitity' => 'edit_theme_options',
      'priority' => 205,
      'title' => __('Design Settings', 'redux')
   ));
   	
	$wp_customize->add_section( 'redux_layout_options', array(
		'title'             => esc_html__( 'Layout Settings', 'redux' ),
		'priority'          => 150,
		'panel'=> 'redux_general_options',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[site_columns]', array(
		'default'           => 'column-2',
		'sanitize_callback' => 'redux_sanitize_column',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[site_columns]', array(
		'label' => __( 'Columns', 'redux' ),
		'section' => 'redux_layout_options',
		'type' => 'radio',
		'choices' => array ('column-1'=>__('1 Column (Site-Wide)', 'redux'), 'column-2'=>__('2 Columns (Site-Wide)', 'redux'), 'column-3'=>__('1 Column (Posts & Pages)', 'redux')),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[site_sidebar]', array(
		'default'           => '0',
		'sanitize_callback' => 'absint',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[site_sidebar]', array(
		'label' => __( 'Sidebar Position', 'redux' ),
		'section' => 'redux_layout_options',
		'type' => 'radio',
		'choices' => array ('0'=>__('Right Sidebar', 'redux'), '1'=>__('Left Sidebar', 'redux')),
	) );
	
   // Start of the Carousel Options
   $wp_customize->add_panel('redux_carousel_options', array(
      'capabitity' => 'edit_theme_options',
      'priority' => 505,
      'title' => __('Carousel Sliders', 'redux')
   ));
   	
	$wp_customize->add_section( 'redux_carousel_header', array(
		'title'             => esc_html__( 'Carousel - Header', 'redux' ),
		'priority'          => 140,
		'panel'=> 'redux_carousel_options',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[header_carousel]', array(
		'default'           => 'off',
		'sanitize_callback' => 'redux_sanitize_onoff',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[header_carousel]', array(
		'label' => __( 'Show Header Carousel', 'redux' ),
		'section' => 'redux_carousel_header',
		'type' => 'radio',
		'choices' => array ('on'=>__('Enable', 'redux'), 'off'=>__('Disable', 'redux')),
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[header_carousel_locations]', array(
		'default'           => array( '1' ),
		'sanitize_callback' => 'sanitize_multiple_select'
	) );

    $wp_customize->add_control(
        new Redux_Customize_Control_Checkbox_Multiple(
            $wp_customize,
            REDUX_THEME_NAME.'[header_carousel_locations]',
            array(
			'section' => 'redux_carousel_header',
			'label'   => __( 'Header Carousel Locations?', 'redux' ),
			'choices' => array (
						'1'=>__('Entire Website', 'redux'),
						'2'=>__('Home / Front Page', 'redux'),
						'3'=>__('Archive Index Pages', 'redux'),
						'4'=>__('Blog Posts', 'redux'),
						'5'=>__('Pages', 'redux'),
						),
            )
        )
    );	

	$wp_customize->add_setting( REDUX_THEME_NAME.'[header_carousel_slides]', array(
		'default'           => '6',
		'sanitize_callback' => 'absint',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[header_carousel_slides]', array(
		'label' => __( 'No. of Slides in Carousel', 'redux' ),
		'section' => 'redux_carousel_header',
		'type' => 'select',
		'choices' => array (
					'3'=>__('Three', 'redux'),
					'6'=>__('Six', 'redux'),
					'9'=>__('Nine', 'redux'),
					'12'=>__('Twelve', 'redux'),
					'15'=>__('Fifteen', 'redux'),
					'18'=>__('Eighteen', 'redux'),
					),
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[header_carousel_categories]', array(
		'default'           => '',
		'sanitize_callback' => 'absint',
	) );
	
	$wp_customize->add_control( 
		new WP_Customize_Category_Control(
		$wp_customize,
		REDUX_THEME_NAME.'[header_carousel_categories]',
		array(
			'label' => __( 'Show Posts in Category', 'redux' ),
			'section'  => 'redux_carousel_header'
        )
    ) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[header_carousel_tags]', array(
		'default'           => '',
		'sanitize_callback' => 'absint',
		
	) );
	
	$wp_customize->add_control( 
		new WP_Customize_Tag_Control(
		$wp_customize,
		REDUX_THEME_NAME.'[header_carousel_tags]',
		array(
			'label' => __( 'Show Posts in Tag', 'redux' ),
			'section'  => 'redux_carousel_header'
        )
    ) );

	$wp_customize->add_section( 'redux_carousel_footer', array(
		'title'             => esc_html__( 'Carousel - Footer', 'redux' ),
		'priority'          => 140,
		'panel'=> 'redux_carousel_options',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[footer_carousel]', array(
		'default'           => 'off',
		'sanitize_callback' => 'redux_sanitize_onoff',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[footer_carousel]', array(
		'label' => __( 'Show Header Carousel', 'redux' ),
		'section' => 'redux_carousel_footer',
		'type' => 'radio',
		'choices' => array ('on'=>__('Enable', 'redux'), 'off'=>__('Disable', 'redux')),
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[footer_carousel_locations]', array(
		'default'           => array( '1' ),
		'sanitize_callback' => 'sanitize_multiple_select'
	) );

    $wp_customize->add_control(
        new Redux_Customize_Control_Checkbox_Multiple(
            $wp_customize,
            REDUX_THEME_NAME.'[footer_carousel_locations]',
            array(
			'section' => 'redux_carousel_footer',
			'label'   => __( 'Header Carousel Locations?', 'redux' ),
			'choices' => array (
						'1'=>__('Entire Website', 'redux'),
						'2'=>__('Home / Front Page', 'redux'),
						'3'=>__('Archive Index Pages', 'redux'),
						'4'=>__('Blog Posts', 'redux'),
						'5'=>__('Pages', 'redux'),
						),
            )
        )
    );	

	$wp_customize->add_setting( REDUX_THEME_NAME.'[footer_carousel_slides]', array(
		'default'           => '6',
		'sanitize_callback' => 'absint',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[footer_carousel_slides]', array(
		'label' => __( 'No. of Slides in Carousel', 'redux' ),
		'section' => 'redux_carousel_footer',
		'type' => 'select',
		'choices' => array (
					'3'=>__('Three', 'redux'),
					'6'=>__('Six', 'redux'),
					'9'=>__('Nine', 'redux'),
					'12'=>__('Twelve', 'redux'),
					'15'=>__('Fifteen', 'redux'),
					'18'=>__('Eighteen', 'redux'),
					),
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[footer_carousel_categories]', array(
		'default'           => '',
		'sanitize_callback' => 'absint',
	) );
	
	$wp_customize->add_control( 
		new WP_Customize_Category_Control(
		$wp_customize,
		REDUX_THEME_NAME.'[footer_carousel_categories]',
		array(
			'label' => __( 'Show Posts in Category', 'redux' ),
			'section'  => 'redux_carousel_footer'
        )
    ) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[footer_carousel_tags]', array(
		'default'           => '',
		'sanitize_callback' => 'absint',
	) );
	
	$wp_customize->add_control( 
		new WP_Customize_Tag_Control(
		$wp_customize,
		REDUX_THEME_NAME.'[footer_carousel_tags]',
		array(
			'label' => __( 'Show Posts in Tag', 'redux' ),
			'section'  => 'redux_carousel_footer'
        )
    ) );
        		
   // End of Carousel Options

	
}
add_action( 'customize_register', 'redux_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview asynchronous.
 */
function redux_customize_preview_js() {
	wp_enqueue_script( 'redux_customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'redux_customize_preview_js' );

/**
 * Sanitize the checkbox.
 *
 * @param boolean $input.
 * @return boolean true if portfolio page template displays title and content.
 */
function redux_sanitize_checkbox( $input ) {
	if ( 1 == $input ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Sanitize the Column value.
 *
 * @param string $column.
 * @return string (column-1|column-2|column-3).
 */
function redux_sanitize_column( $column ) {
	if ( ! in_array( $column, array( 'column-1', 'column-2', 'column-3' ) ) ) {
		$column = 'column-1';
	}
	return $column;
}

// yes/no radio sanitize
function redux_sanitize_yesno($input) {
	if ( $input == 'yes' ) {
		return 'yes';
	} else {
		return 'no';
      }
}
   
// On/Off radio sanitize
function redux_sanitize_onoff($input) {
	if ( $input == 'on' ) {
		return 'on';
	} else {
		return 'off';
	}
}
   
// Dark/Light radio sanitize
function redux_sanitize_darklight($input) {
	if ( $input == 'dark' ) {
		return 'dark';
	} else {
		return 'light';
	}
}
   
// color sanitization
function redux_color_option_hex_sanitize($color) {
	if ($unhashed = sanitize_hex_color_no_hash($color))
		return '#' . $unhashed;
	return $color;
}

function redux_color_escaping_option_sanitize($input) {
	$input = sanitize_text_field($input);
	return $input;
}