<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Redux
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function redux_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	
	// Add a class of no-sidebar when there is no sidebar present
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'redux_body_classes' );

/**
 * Filter the "read more" excerpt string link to the post.
 *
 * @param string $more "Read more" excerpt string.
 * @return string (Maybe) modified "read more" excerpt string.
 */
function wpdocs_excerpt_more( $more ) {
    return (' [...] ');
}
add_filter( 'excerpt_more', 'wpdocs_excerpt_more' );

/**
 * Add the "read more" link to the post excerpts, both auto and custom.
 *
 * @param string $excerpt "Read more" excerpt string.
 * @return string (Maybe) modified "Read more" excerpt string.
 */

function the_excerpt_more_link( $excerpt ){
    $excerpt .= sprintf(
    			/* translators: %s: Link & Name of current post. */
			wp_kses( __( '<p class="read-more"><a href="%s" rel="nofollow">Read more %s</a></p>', 'redux' ), array( 'span' => array( 'class' => array() ), 'a' => array( 'href' => array(), 'title' => array() ), 'p' => array( 'class' => array() ) ) ),
			get_the_permalink(),
			the_title('<span class="screen-reader-text">"', '"</span>', false )
			);
    return $excerpt;
}
add_filter( 'the_excerpt', 'the_excerpt_more_link', 21 );