<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Redux
 */

if ( ! function_exists( 'redux_post_date' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @param string $before to add/modify text before the output.
 * @param string $after to add/modify text after the output. 
 * @param string $class to add class to the output span. 
 */
function redux_post_date($before=NULL,$after=NULL,$class=NULL) {
	
	if (!isset($class)) {
		$class='postmeta-date';
	}

	$beforetag = '<span class="'. $class .'">';

	if (!isset($before)) {
		$before = _x('Date: ', 'date label', 'redux');
	}

	$aftertag = '</span>';

	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';
	
	return print($beforetag . $before . $posted_on . $after . $aftertag);
	
}
endif;


if ( ! function_exists( 'redux_post_author' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @param string $before to add/modify text before the output.
 * @param string $after to add/modify text after the output. 
 * @param string $class to add class to the output span. 
 */
function redux_post_author($before=NULL,$after=NULL,$class=NULL) {
	
	if (!isset($class)) {
		$class='postmeta-author';
	}

	$beforetag = '<span class="'. $class .'">';

	if (!isset($before)) {
		$before = _x('Author: ', 'author label', 'redux');
	}

	$aftertag = '</span>';
	
	$byline = '<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>';
	
	return print($beforetag . $before . $byline . $after . $aftertag);
}
endif;

if ( ! function_exists( 'redux_post_categories' ) ) :
/**
 * Prints HTML with meta information for the current post categories.
 *
 * @param string $before to add/modify text before the output.
 * @param string $after to add/modify text after the output. 
 * @param string $class to add class to the output span. 
 */
function redux_post_categories($before=NULL,$after=NULL,$class=NULL, $seperator=NULL) {

	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {

		if (!isset($class)) {
			$class='postmeta-categories';
		}

		if (isset($class) && $class!='') {	
			$beforetag = '<span class="'. $class .'">';
		} else {
			$beforetag = '';
		}
	
		if (!isset($before)) {
			$before = _x('Categories: ', 'categories label', 'redux');
		}
	
		if (isset($class) && $class!='') {	
			$aftertag = '</span>';
		} else {
			$aftertag = '';		
		}

		if (isset($seperator) && $seperator!='') {	
			$sep = $seperator;
		} elseif (isset($seperator) && $seperator==='') {	
			$sep = ' ';		
		} else {
			$sep = ', ';		
		}

		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( $sep );
		if ( $categories_list && redux_categorized_blog() ) {
			$post_cats = '<span class="cat-links">' . $categories_list . '</span>' ; // WPCS: XSS OK.
				
			return print($beforetag . $before . $post_cats . $after . $aftertag);
		
		}
	}

}
endif;

if ( ! function_exists( 'redux_post_tags' ) ) :
/**
 * Prints HTML with meta information for the current post tags.
 * @param string $before to add/modify text before the output.
 * @param string $after to add/modify text after the output. 
 * @param string $class to add class to the output span. 
 */
function redux_post_tags($before=NULL,$after=NULL,$class=NULL) {

	if (!isset($class)) {
		$class='postmeta-tags';
	}

	$beforetag = '<span class="'. $class .'">';

	if (!isset($before)) {
		$before = _x('Tags: ', 'tags label', 'redux');
	}

	$aftertag = '</span>';

	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'redux' ) );
		if ( $tags_list ) {
			$post_tags = '<span class="tags-links">' . $tags_list . '</span>'; // WPCS: XSS OK.

			return print($beforetag . $before . $post_tags . $after . $aftertag);
		}
	}

}
endif;

if ( ! function_exists( 'redux_post_comments' ) ) :
/**
 * Prints HTML with meta information for the comments.
 */
function redux_post_comments() {

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo ' <span class="comments-link">';
		comments_popup_link( esc_html__( 'Leave a comment', 'redux' ), esc_html__( '1 Comment', 'redux' ), esc_html__( '% Comments', 'redux' ) );
		echo '</span>';
	}

}
endif;

if ( ! function_exists( 'redux_post_edit' ) ) :
/**
 * Prints HTML with meta information for the comments.
 */
function redux_post_edit() {

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'redux' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);

}
endif;

if ( ! function_exists( 'redux_featured_image' ) ) :
/**
 * Prints HTML with featured image for the post.
 * @params string $featured_image_size to set the image size to show, default = large, also accepts array(width, height) eg: array(100, 100)
 * @param string $class to add class to the figure tag. 
 * @param string $before to add text/HTML before the output.
 * @param string $after to add text/HTML after the output. 
 */
function redux_featured_image($size=NULL,$class=NULL) {

	if ( ! has_post_thumbnail() ) return;
	
	if (!isset($size)) {
		$size='large';
	}
	
	if (!isset($class)) {
		$class='featured-image';
	}

	$image_tag_start = '<figure class="'.$class.'">';
	$image_tag_close = '</figure>';
	$link_start = '<a href="' . get_permalink() . '" alt="' . esc_attr( get_the_title() ) . '">';
	$link_end = '</a>';
	
	print $image_tag_start . $link_start;
	the_post_thumbnail ( $size ); 
	print $link_end . $image_tag_close;
	return;	
	
}
endif;

if ( ! function_exists( 'redux_post_title' ) ) :
/**
 * Prints HTML with the post title.
 */
function redux_post_title() {
	
	if ( is_singular() ) {
		the_title( '<h1 class="entry-title">', '</h1>' );
	} else {
		the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );
	}

}
endif;

			
/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function redux_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'redux_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'redux_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so redux_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so redux_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in redux_categorized_blog.
 */
function redux_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'redux_categories' );
}
add_action( 'edit_category', 'redux_category_transient_flusher' );
add_action( 'save_post',     'redux_category_transient_flusher' );